"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Canvas2DContextService = void 0;

var _tslib = require("tslib");

var _g = require("@antv/g");

var _manaSyringe = require("mana-syringe");

var _util = require("@antv/util");

var _dom = require("./utils/dom");

var Canvas2DContextService =
/** @class */
function () {
  function Canvas2DContextService() {}

  Canvas2DContextService.prototype.init = function () {
    var _a = this.canvasConfig,
        container = _a.container,
        width = _a.width,
        height = _a.height; // create container

    this.$container = (0, _util.isString)(container) ? document.getElementById(container) : container;

    if (this.$container) {
      // create canvas
      var $canvas = document.createElement('canvas');
      this.context = $canvas.getContext('2d');
      this.$container.appendChild($canvas);

      if (!this.$container.style.position) {
        this.$container.style.position = 'relative';
      }

      this.$canvas = $canvas;
      var dpr = window.devicePixelRatio || 1;
      dpr = dpr >= 1 ? Math.ceil(dpr) : 1;
      this.dpr = dpr;
      this.resize(width, height);
    }
  };

  Canvas2DContextService.prototype.getContext = function () {
    return this.context;
  };

  Canvas2DContextService.prototype.getDomElement = function () {
    return this.$canvas;
  };

  Canvas2DContextService.prototype.getDPR = function () {
    return this.dpr;
  };

  Canvas2DContextService.prototype.getBoundingClientRect = function () {
    var _a;

    return (_a = this.$canvas) === null || _a === void 0 ? void 0 : _a.getBoundingClientRect();
  };

  Canvas2DContextService.prototype.destroy = function () {
    if (this.$container && this.$canvas && this.$canvas.parentNode) {
      // destroy context
      this.$container.removeChild(this.$canvas);
    }
  };

  Canvas2DContextService.prototype.resize = function (width, height) {
    if (this.$canvas) {
      // set canvas width & height
      this.$canvas.width = this.dpr * width;
      this.$canvas.height = this.dpr * height; // set CSS style width & height

      (0, _dom.setDOMSize)(this.$canvas, width, height);
      var dpr = this.getDPR(); // scale all drawing operations by the dpr
      // @see https://www.html5rocks.com/en/tutorials/canvas/hidpi/

      this.context.scale(dpr, dpr);
    }
  };

  Canvas2DContextService.prototype.applyCursorStyle = function (cursor) {
    if (this.$container) {
      this.$container.style.cursor = cursor;
    }
  };

  (0, _tslib.__decorate)([(0, _manaSyringe.inject)(_g.CanvasConfig), (0, _tslib.__metadata)("design:type", Object)], Canvas2DContextService.prototype, "canvasConfig", void 0);
  Canvas2DContextService = (0, _tslib.__decorate)([(0, _manaSyringe.singleton)({
    token: _g.ContextService
  })], Canvas2DContextService);
  return Canvas2DContextService;
}();

exports.Canvas2DContextService = Canvas2DContextService;